// See instructions on how to make new AI configs in iai.html.
// ----------------------------------------------------------------------
// This code was adapted for IAI from Orogogus' PlayerClone.cs.
// Here the vehicle profile is also used as the file name, with extension
// ".dat" instead of ".veh".  Also the index is auto-incremented so items
// in the list can easily be inserted, deleted, or otherwise rearranged.
//
// The format is: <Chassis>-<Weapon1>-<Weapon2>...-<Other Components>

$IAI::VehFile = "ListAll.cs";

exec($IAI::VehFile);

function IAI::copyVehicle(%player) {
  %vehicle = playermanager::playerNumToVehicleID(%player);
  %profile = IAI::analyzeVeh(%vehicle);
  for(%i=1; %i<=$IAI::VehN; %i++)
    if($IAI::Veh[%i] == %profile) return;
  IAI::Msg("Cloned new vehicle "@$IAI::VehN);
  %fn = %profile @ ".dat";
  storeObject(%vehicle,%fn);
  $IAI::VehN++;
  $IAI::Veh[$IAI::VehN] = %profile;
  IAI::writeVehicleList(%profile);
}

function IAI::writeVehicleList(%profile) {
  $placeHolder = "IAI Vehicle List";
  %fn = $IAI::VehFile;
  export("$placeHolder", %fn, overwrite);
  fileWrite( %fn, append, "%i = 0;");
  for(%i=1; %i<=$IAI::VehN; %i++)
    fileWrite( %fn, append,
		"$IAI::Veh[%i++] = \"" @ $IAI::Veh[%i] @ "\";");
  fileWrite( %fn, append, "$IAI::VehN = %i;");
  IAI::Msg("Saved "@$IAI::VehN@" records to "@%fn);
}

//=======

function IAI::analyzeVeh(%this)
{
  %componentCount = getComponentCount(%this);

  %output = getVehicleName(%this);

  %weaponCount = getWeaponCount(%this);
  %index = 0;
  while (%index < %weaponCount) 
  {
    %id = getWeaponId(%this, %index);
    %theName = nameGun(%id);
    %output = %output @ "-" @ %theName;
    %index++;
  }

  %index = 0;
  while (%index < %componentCount) 
  {
    %id = getComponentId(%this, %index);
    %theName = nameStuff(%id);
    %output = %output @ "-" @ %theName;
    %index++;
  }

  echo(%output);
  return(%output);
}


function nameStuff(%x)
{
	if ((%x >= 100) && (%x <= 115))
	{
		return(nameEngineA(%x));
	}

	else if ((%x >= 128) && (%x <= 143))
	{
		return(nameEngineB(%x));
	}

	else if ((%x >= 200) && (%x <=230))
	{
		return(nameReactor(%x));
	}

	else if ((%x >= 300) && (%x <= 333))
	{
		return(nameShield(%x));
	}

	else if ((%x >= 400) && (%x <= 434))
	{
		return(nameSensor(%x));
	}

	else if ((%x >= 800) && (%x <= 807))
	{
		return(nameComputer(%x));
	}

	else if ((%x >= 926) && (%x <= 931))
	{
		return(nameArmor(%x));
	}

	else if ((%x >= 810) && (%x <= 914))
	{
		return(nameSpecial(%x));
	}

	else return("Unknown component");
}


function nameEngineA(%x)
{
	if(%x == 100)
	{
		return("HumanLight");
	}
	else if(%x == 101)
	{
		return("HumanHighOutput");
	}
	else if(%x == 102)
	{
		return("HumanLightAgility");
	}
	else if(%x == 103)
	{
		return("HumanStandardMedium");
	}
	else if(%x == 104)
	{
		return("HumanHighOutputMedium");
	}
	else if(%x == 105)
	{
		return("HumanMediumAgility");
	}
	else if(%x == 106)
	{
		return("HumanStandardHeavy");
	}
	else if(%x == 107)
	{
		return("HumanImprovedHeavy");
	}
	else if(%x == 108)
	{
		return("HumanHeavyCruise");
	}
	else if(%x == 109)
	{
		return("HumanHighOutputHeavy");
	}
	else if(%x == 110)
	{
		return("HumanHeavyAgility");
	}
	else if(%x == 111)
	{
		return("HumanStandardAssault");
	}
	else if(%x == 112)
	{
		return("HumanImprovedAssault");
	}
	else if(%x == 113)
	{
		return("HumanHeavyTurbine");
	}
	else if(%x == 114)
	{
		return("HumanHighOutputTurbine");
	}
	else if(%x == 115)
	{
		return("HumanSuperHeavy");
	}
	else return("Error");
}

function nameEngineB(%x)
{
	if(%x == 128)
	{
		return("CybridLightVehicle");
	}
	else if(%x == 129)
	{
		return("CybridLightAgility");
	}
	else if(%x == 130)
	{
		return("CybridStandardMedium");
	}
	else if(%x == 131)
	{
		return("CybridMediumCruise");
	}
	else if(%x == 132)
	{
		return("CybridImprovedMedium");
	}
	else if(%x == 133)
	{
		return("CybridMediumHighOutput");
	}
	else if(%x == 134)
	{
		return("CybridMediumAgility");
	}
	else if(%x == 135)
	{
		return("CybridStandardHeavy");
	}
	else if(%x == 136)
	{
		return("CybridHeavyHighOutput");
	}
	else if(%x == 137)
	{
		return("CybridHeavyAgility");
	}
	else if(%x == 138)
	{
		return("CybridStandardAssault");
	}
	else if(%x == 139)
	{
		return("CybridImprovedAssault");
	}
	else if(%x == 140)
	{
		return("CybridHighOutputAssault");
	}
	else if(%x == 141)
	{
		return("CybridHeavyAssault");
	}
	else if(%x == 142)
	{
		return("CybridHeavyAssaultTurbine");
	}
	else if(%x == 143)
	{
		return("CybridPiSuperHeavy");
	}
	else return("Error");
}


function nameReactor(%x)
{
	if (%x == 200)
	{
		return("HMicroReactor");
	}
	else if(%x == 201)
	{
		return("HSmallReactor");
	}
	else if(%x == 202)
	{
		return("HStandardReactor");
	}
	else if(%x == 203)
	{
		return("HMediumReactor");
	}
	else if(%x == 204)
	{
		return("HLargeReactor");
	}
	else if(%x == 205)
	{
		return("HMaximReactor");
	}
	else if(%x == 225)
	{
		return("CAlphaReactor");
	}
	else if(%x == 226)
	{
		return("CBetaReactor");
	}
	else if(%x == 227)
	{
		return("CGammaReactor");
	}
	else if(%x == 228)
	{
		return("CDeltaReactor");
	}
	else if(%x == 229)
	{
		return("CEpsilonReactor");
	}
	else if(%x == 230)
	{
		return("CThetaReactor");
	}
	else return("Unknown reactor");
}


function nameShield(%x)
{
	if(%x == 300)
	{
		return("StandardShield");
	}
	else if(%x == 301)
	{
		return("ProtectorShield");
	}
	else if(%x == 302)
	{
		return("GuardianShield");
	}
	else if(%x == 303)
	{
		return("FastChargeShield");
	}
	else if(%x == 304)
	{
		return("CenturionShield");
	}
	else if(%x == 305)
	{
		return("RepulsorShield");
	}
	else if(%x == 306)
	{
		return("TitanShield");
	}
	else if(%x == 307)
	{
		return("MedusaShield");
	}
	else if(%x == 326)
	{
		return("AlphaShield");
	}
	else if(%x == 327)
	{
		return("BetaShield");
	}
	else if(%x == 328)
	{
		return("GammaShield");
	}
	else if(%x == 329)
	{
		return("DeltaShield");
	}
	else if(%x == 330)
	{
		return("EpsilonShield");
	}
	else if(%x == 331)
	{
		return("ZetaShield");
	}
	else if(%x == 332)
	{
		return("EtaShield");
	}
	else if(%x == 333)
	{
		return("ThetaShield");
	}
	else return("Error");
}



function nameSensor(%x)
{
	if(%x == 400)
	{
		return("HBasicSensor");
	}
	else if(%x == 401)
	{
		return("Human Ranger Sensor");
	}
	else if(%x == 408)
	{
		return("HStandardSensor");
	}
	else if(%x == 409)
	{
		return("HLongbowSensor");
	}
	else if(%x == 410)
	{
		return("HInfiltratorSensor");
	}
	else if(%x == 411)
	{
		return("HCrossbowSensor");
	}
	else if(%x == 412)
	{
		return("HUltralightSensor");
	}
	else if(%x == 413)
	{
		return("HHoundSensor");
	}
	else if(%x == 414)
	{
		return("HThermalSensor");
	}
	else if(%x == 426)
	{
		return("Alpha SensorBasic");
	}
	else if(%x == 427)
	{
		return("BetaSensorLongRange");
	}
	else if(%x == 428)
	{
		return("GammaSensorStandard");
	}
	else if(%x == 429)
	{
		return("DeltaSensorLongbow");
	}
	else if(%x == 430)
	{
		return("EpsilonSensorInfiltrator");
	}
	else if(%x == 431)
	{
		return("ZetaSensorCrossbow");
	}
	else if(%x == 432)
	{
		return("EtaSensorUltralight");
	}
	else if(%x == 433)
	{
		return("ThetaSensorHound");
	}
	else if(%x == 434)
	{
		return("IotaSensorMotionDetector");
	}
	else return("Error");
}





function nameArmor(%x)
{
	if(%x == 926)
	{
		return("Carlam");
	}
	else if(%x == 927)
	{
		return("Quad");
	}
	else if(%x == 928)
	{
		return("Durac");
	}
	else if(%x == 929)
	{
		return("Ceramic");
	}
	else if(%x == 930)
	{
		return("Crystal");
	}
	else if(%x == 931)
	{
		return("Quicksilver");
	}
	else return("Error");
}



function nameComputer(%x)
{
	if(%x == 800)
	{
		return("166");
	}
	else if(%x == 801)
	{
		return("300");
	}
	else if(%x == 802)
	{
		return("450");
	}
	else if(%x == 805)
	{
		return("AlphaComp");
	}
	else if(%x == 806)
	{
		return("BetaComp");
	}
	else if(%x == 807)
	{
		return("GammaComp");
	}
	else return("Unknown computer");
}


function nameSpecial(%x)
{
	if(%x == 810)
	{
		return("Guardian");
	}
	else if(%x == 811)
	{
		return("Doppleganger");
	}
	else if(%x == 812)
	{
		return("AlphaECM");
	}
	else if(%x == 813)
	{
		return("BetaECM");
	}
	else if(%x == 820)
	{
		return("ThermalDiff");
	}
	else if(%x == 830)
	{
		return("Chameleon");
	}
	else if(%x == 831)
	{
		return("Cuttlefish");
	}
	else if(%x == 840)
	{
		return("SMod");
	}
	else if(%x == 845)
	{
		return("SCap");
	}
	else if(%x == 850)
	{
		return("SAmp");
	}
	else if(%x == 860)
	{
		return("LTAG");
	}
	else if(%x == 865)
	{
		return("AuxPower");
	}
	else if(%x == 870)
	{
		return("RCap");
	}
	else if(%x == 875)
	{
		return("FieldStab");
	}
	else if(%x == 880)
	{
		return("Rocket");
	}
	else if(%x == 885)
	{
		return("Turbine");
	}
	else if(%x == 890)
	{
		return("Nanorepair");
	}
	else if(%x == 900)
	{
		return("Angel");
	}
	else if(%x == 910)
	{
		return("AntiGrav");
	}
	else if(%x == 912)
	{
		return("Electrohull");
	}
	else if(%x == 914)
	{
		return("Ammopack");
	}
}

function nameGun(%x)
{
	if ((%x >= 1) && (%x <= 119))
	{
		return(nameGunA(%x));
	}

	else
	{
		return(nameGunB(%x));
	}
}


function nameGunA(%x)
{
	if(%x == 3)
	{
		return("Disrupter");
	}
	else if(%x == 101)
	{
		return("Las");
	}
	else if(%x == 102)
	{
		return("HLas");
	}
	else if(%x == 103)
	{
		return("CLas");
	}
	else if(%x == 104)
	{
		return("TLas");
	}
	else if(%x == 105)
	{
		return("EMP");
	}
	else if(%x == 106)
	{
		return("ELF");
	}
	else if(%x == 107)
	{
		return("Blaster");
	}
	else if(%x == 108)
	{
		return("HBlaster");
	}
	else if(%x == 109)
	{
		return("PBW");
	}
	else if(%x == 110)
	{
		return("Plasma");
	}
	else if(%x == 111)
	{
		return("Blink");
	}
	else if(%x == 112)
	{
		return("QGun");
	}
	else if(%x == 113)
	{
		return("MFAC");
	}
	else if(%x == 114)
	{
		return("Nano-infuser");
	}
	else if(%x == 115)
	{
		return("NaniteCannon");
	}
	else if(%x == 116)
	{
		return("ATC");
	}
	else if(%x == 117)
	{
		return("HATC");
	}
	else if(%x == 118)
	{
		return("EMC");
	}
	else if(%x == 119)
	{
		return("BC");
	}
	else return("Error");
}

function nameGunB(%x)
{
	if(%x == 120)
	{
		return("HBC");
	}
	else if(%x == 121)
	{
		return("Railgun");
	}
	else if(%x == 124)
	{
		return("PitViper8");
	}
	else if(%x == 125)
	{
		return("PitViper12");
	}
	else if(%x == 126)
	{
		return("Sparrow6");
	}
	else if(%x == 127)
	{
		return("Sparrow10");
	}
	else if(%x == 128)
	{
		return("Swarm6");
	}
	else if(%x == 129)
	{
		return("Minion");
	}
	else if(%x == 130)
	{
		return("Shrike");
	}
	else if(%x == 131)
	{
		return("Arach4");
	}
	else if(%x == 132)
	{
		return("Arach8");
	}
	else if(%x == 133)
	{
		return("Arach12");
	}
	else if(%x == 134)
	{
		return("HHG6");
	}
	else if(%x == 135)
	{
		return("HHG10");
	}
	else if(%x == 136)
	{
		return("HHG15");
	}
	else if(%x == 142)
	{
		return("Radgun");
	}
	else if(%x == 147)
	{
		return("Aphid");
	}
	else if(%x == 150)
	{
		return("SGun");
	}
	else return("Error");
}

function vehicle::onAdd(%vehicleID)
{
  %player = playerManager::vehicleIDToPlayerNum(%vehicleID);
  if(%player == 0) return;
  IAI::copyVehicle(%player);
}
